# SEC04-BP02: Capture logs in standardized locations

## Description

Centralized logging.

## Implementation Guidance

- Centralized log aggregation
- Standardized log format
- Log retention policies
- Immutable log storage
- Cross-account log collection

## Risk Level

High - Scattered logs are hard to investigate.
